<?php

namespace Drupal\redirects_fixer\Entity;

use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Entity\ContentEntityBase;
use Drupal\Core\Field\BaseFieldDefinition;

/**
 * Defines the Link Log Entity type.
 *
 * @ContentEntityType(
 *   id = "redirects_fixer_log",
 *   label = @Translation("Redirects Fixer Log Item"),
 *   base_table = "redirects_fixer_log",
 *   entity_keys = {
 *     "id" = "id",
 *   },
 *   fieldable = TRUE,
 *   admin_permission = "administer redirects fixer log entity",
 *   handlers = {
 *     "storage" = "Drupal\Core\Entity\Sql\SqlContentEntityStorage",
 *     "views_data" = "Drupal\views\EntityViewsData",
 *   }
 * )
 */
class RedirectsFixerLogEntity extends ContentEntityBase {

  /**
   * {@inheritdoc}
   */
  public static function baseFieldDefinitions(EntityTypeInterface $entity_type) {
    $fields = parent::baseFieldDefinitions($entity_type);

    $fields['entity_id'] = BaseFieldDefinition::create('integer')
      ->setLabel(t('Entity ID'))
      ->setRequired(TRUE);

    $fields['entity_type'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Entity Type'))
      ->setRequired(TRUE);

    $fields['time'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Time'))
      ->setRequired(TRUE);

    $fields['old_type'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Old Type'))
      ->setRequired(TRUE);

    $fields['new_type'] = BaseFieldDefinition::create('string')
      ->setLabel(t('New Type'))
      ->setRequired(TRUE);

    $fields['old_url'] = BaseFieldDefinition::create('uri')
      ->setLabel(t('Old URL'))
      ->setRequired(TRUE);

    $fields['new_url'] = BaseFieldDefinition::create('uri')
      ->setLabel(t('New URL'))
      ->setRequired(TRUE);

    return $fields;
  }


}
