<?php

namespace Drupal\redirects_fixer\Plugin\views\field;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Entity\EntityStorageInterface;
use Drupal\redirects_fixer\Entity\RedirectsFixerLogEntity;
use Drupal\views\Plugin\views\field\FieldPluginBase;
use Drupal\views\ResultRow;


/**
* A handler to provide a field that is completely custom by the administrator.
*
* @ingroup views_field_handlers
*
* @ViewsField("redirect_fixer_log_link_to_base_entity")
*/
class RedirectFixerLogLinkToBaseEntity extends FieldPluginBase {

  /**
  * @{inheritdoc}
  */
  public function query() {
  // Leave empty to avoid a query on this field.
  }

  /**
  * @{inheritdoc}
  */
  public function render(ResultRow $values) {
    /** @var RedirectsFixerLogEntity $RedirectsFixerLogEntity */
    $redirects_fixer_log_entity = $values->_entity;
    $entity_type = $redirects_fixer_log_entity->entity_type->value;

    $entity_type_manager = \Drupal::entityTypeManager()->getStorage($entity_type);
    if (!$entity_type_manager instanceof EntityStorageInterface) {
      return ['#markup' => 'Cannot load data for this field'];
    }

    $entity_id = $redirects_fixer_log_entity->entity_id->value;
    $entity = $entity_type_manager->load($entity_id);

    if (!$entity instanceof ContentEntityInterface) {
      return ['#markup' => 'Cannot load entity'];
    }

    $link = $entity->toUrl();
    $title = $entity->label();
    return [
      '#type' => 'link',
      '#url' => $link,
      '#title' => $title,
    ];
  }
}
